@@ -65,50 +65,47 @@ use Scalar::Util qw(reftype);
 use Time::Local;
 
 use constant {  ## no critic (ProhibitConstantPragma, Capitalization)
-  AWS_AVAILABILITY_ZONE_URL =>
-    q{latest/meta-data/placement/availability-zone},
+  AWS_AVAILABILITY_ZONE_URL        => q{latest/meta-data/placement/availability-zone},
   AWS_CONTAINER_CREDENTIALS_URL    => q{http://169.254.170.2/},
-  AWS_IAM_SECURITY_CREDENTIALS_URL =>
-    q{latest/meta-data/iam/security-credentials/},
-  AWS_METADATA_BASE_URL         => q{http://169.254.169.254/},
-  CACHE_DIR                     => '.aws/sso/cache',
-  COMMA                         => q{,},
-  DEFAULT_CIPHER                => q{Cipher::AES},
-  DEFAULT_REGION                => 'us-east-1',
-  DEFAULT_SEARCH_ORDER          => q{env,container,role,file},
-  DEFAULT_TIMEOUT               => 2,
-  DEFAULT_WINDOW_INTERVAL       => 5,
-  EMPTY                         => q{},
-  FALSE                         => 0,
-  GET_ROLE_CREDENTIALS_HOSTNAME => 'portal.sso.%s.amazonaws.com',
-  GET_ROLE_CREDENTIALS_QUERY    => '?account_id=%s&role_name=%s',
-  GET_ROLE_CREDENTIALS_URI      => 'federation/credentials',
-  IMDSv2_DEFAULT_TTL            => 21_600,
-  IMDSv2_HEADER                 => q{x-aws-ec2-metadata-token},
-  IMDSv2_TTL_HEADER             => q{x-aws-ec2-metadata-token-ttl-seconds},
-  IMDSv2_URL                    => q{latest/api/token},
-  INSECURE_MODE                 => 2,
-  ISO8601_FORMAT                => q{%Y-%m-%dT%H:%M:%S%z},
-  LOG_FORMAT                    => qq{ %s [%s] %s\n },
-  PASSKEY_FORMAT                => q{%08X%08x},
-  RANDOM_VALUE                  => 0xffffffff,
-  SECONDS_IN_HOUR               => 3600,
-  SECONDS_IN_MINUTE             => 60,
-  SUCCESS                       => 0,
-  FAILURE                       => 1,
-  SLASH                         => q{/},
-  TRUE                          => 1,
-  X_AMZ_SSO_BEARER_TOKEN        => ':x-amz-sso_bearer_token',
+  AWS_IAM_SECURITY_CREDENTIALS_URL => q{latest/meta-data/iam/security-credentials/},
+  AWS_METADATA_BASE_URL            => q{http://169.254.169.254/},
+  CACHE_DIR                        => '.aws/sso/cache',
+  COMMA                            => q{,},
+  DEFAULT_CIPHER                   => q{Cipher::AES},
+  DEFAULT_REGION                   => 'us-east-1',
+  DEFAULT_SEARCH_ORDER             => q{env,container,role,file},
+  DEFAULT_TIMEOUT                  => 2,
+  DEFAULT_WINDOW_INTERVAL          => 5,
+  EMPTY                            => q{},
+  FALSE                            => 0,
+  GET_ROLE_CREDENTIALS_HOSTNAME    => 'portal.sso.%s.amazonaws.com',
+  GET_ROLE_CREDENTIALS_QUERY       => '?account_id=%s&role_name=%s',
+  GET_ROLE_CREDENTIALS_URI         => 'federation/credentials',
+  IMDSv2_DEFAULT_TTL               => 21_600,
+  IMDSv2_HEADER                    => q{x-aws-ec2-metadata-token},
+  IMDSv2_TTL_HEADER                => q{x-aws-ec2-metadata-token-ttl-seconds},
+  IMDSv2_URL                       => q{latest/api/token},
+  INSECURE_MODE                    => 2,
+  ISO8601_FORMAT                   => q{%Y-%m-%dT%H:%M:%S%z},
+  LOG_FORMAT                       => qq{ %s [%s] %s\n },
+  PASSKEY_FORMAT                   => q{%08X%08x},
+  RANDOM_VALUE                     => 0xffffffff,
+  SECONDS_IN_HOUR                  => 3600,
+  SECONDS_IN_MINUTE                => 60,
+  SUCCESS                          => 0,
+  FAILURE                          => 1,
+  SLASH                            => q{/},
+  TRUE                             => 1,
+  X_AMZ_SSO_BEARER_TOKEN           => ':x-amz-sso_bearer_token',
 };
 
-our $VERSION = '1.1.24';  ## no critic (RequireInterpolation)
+our $VERSION = '1.1.25';  ## no critic (RequireInterpolation)
 
-our @EXPORT_OK
-  = qw( create_passkey set_sso_credentials get_role_credentials );
+our @EXPORT_OK = qw( create_passkey set_sso_credentials get_role_credentials );
 
 # we only log at debug level, create a default logger
 {
-  no strict 'refs';  ## no critic (ProhibitNoStrict)
+  no strict 'refs';                  ## no critic (ProhibitNoStrict)
 
   *{'Amazon::Credentials::Logger::debug'} = sub {
     my ( $self, @message ) = @_;
@@ -183,8 +180,7 @@ WARNING
     my $region = $self->get_sso_region || $self->get_region;
 
     # this just sets the environmet
-    set_sso_credentials( $self->get_sso_role_name, $self->get_sso_account_id,
-      $region );
+    set_sso_credentials( $self->get_sso_role_name, $self->get_sso_account_id, $region );
 
     # we'll set them from the environment below
     $self->set_order( ['env'] );
@@ -203,15 +199,13 @@ WARNING
     }
   }
   else {
-    $self->get_logger->debug( 'setting credentials from options ',
-      Dumper( [$options] ) );
+    $self->get_logger->debug( 'setting credentials from options ', Dumper( [$options] ) );
 
     $self->set_credentials($options);
   }
 
   if ( !$self->get_region ) {
-    $self->set_region( $self->get_region_from_env
-        || $self->get_default_region );
+    $self->set_region( $self->get_region_from_env || $self->get_default_region );
   }
 
   return $self;
@@ -286,7 +280,7 @@ sub get_default_region {
 
     # add imdsv2 token to metadata request
     if ( !$self->get_container && $self->get_imdsv2_token ) {
-      @headers = ( IMDSv2_HEADER => $self->get_imdsv2_token );
+      @headers = ( IMDSv2_HEADER, $self->get_imdsv2_token );
     }
 
     my $req = HTTP::Request->new( GET => $url, \@headers );
@@ -585,8 +579,7 @@ sub get_creds_from_ini_file {
       $section = $ini->{"profile $profile_name"};
     }
 
-    my $process
-      = $ini->{credential_process} || $section->{credential_process};
+    my $process = $ini->{credential_process} || $section->{credential_process};
 
     if ($process) {
       $creds  = $self->get_creds_from_process($process);
@@ -608,8 +601,7 @@ sub get_creds_from_ini_file {
 
       $creds = populate_creds( $config, \@cred_keys, $section );
 
-      if ( !$creds->{aws_access_key_id} || !$creds->{aws_secret_access_key} )
-      {
+      if ( !$creds->{aws_access_key_id} || !$creds->{aws_secret_access_key} ) {
         $creds = {};
       }
     }
@@ -628,8 +620,7 @@ sub get_creds_from_role {
   my $aws_ec2_metadata_disabled = $ENV{AWS_EC2_METADATA_DISABLED} // EMPTY;
 
   if ( $aws_ec2_metadata_disabled eq 'true' ) {
-    $self->get_logger->debug(
-      'AWS_EC2_METADATA_DISABLED is true, skipping...');
+    $self->get_logger->debug('AWS_EC2_METADATA_DISABLED is true, skipping...');
 
     return {};
   }
@@ -650,7 +641,7 @@ sub get_creds_from_role {
 
     my $token_req = HTTP::Request->new( PUT => $token_url, \@headers );
 
-    $self->get_logger->debug( Dumper $token_req);
+    $self->get_logger->debug( Dumper $token_req );
 
     my $rsp = $ua->request($token_req);
 
@@ -732,8 +723,7 @@ sub get_creds_from_container {
   my $creds = {};
 
   if ( !$uri ) {
-    $self->get_logger->debug(
-      "not running in a container: no URI in environment\n");
+    $self->get_logger->debug("not running in a container: no URI in environment\n");
     return $creds;
   }
 
@@ -809,11 +799,9 @@ sub safe_dumper {
   elsif ( $self->get_insecure ) {
     $safe_rsp = Dumper [$obj];
 
-    $safe_rsp
-      =~ s/(.*?)(access_?key[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/ixsmg;
+    $safe_rsp =~ s/(.*?)(access_?key[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/ixsmg;
 
-    $safe_rsp
-      =~ s/(.*?)(secret_?access[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/ixsmg;
+    $safe_rsp =~ s/(.*?)(secret_?access[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/ixsmg;
 
     $safe_rsp =~ s/(.*?)(token[^']+)'([^']+)'([^']+)'/$1$2'$3'...'/ixsmg;
   }
@@ -840,8 +828,7 @@ sub dump_response {
     foreach my $k ( keys %{$rsp} ) {
       if ( $k =~ /content/xsm ) {
         my $content = $rsp->{$k};
-        $content
-          =~ s/\"(AccessKeyId|Token|SecretAccessKey)\"\s+\:\s+\"[^\"]+\"/\"$1\" : \"...\"/gxsm;
+        $content =~ s/\"(AccessKeyId|Token|SecretAccessKey)\"\s+\:\s+\"[^\"]+\"/\"$1\" : \"...\"/gxsm;
         $safe_rsp->{$k} = $content;
       }
       else {
@@ -884,14 +871,11 @@ sub is_token_expired {
       $self->get_logger->debug("seconds left : $seconds_left");
       my $hours = int( $seconds_left / SECONDS_IN_HOUR );
 
-      my $minutes = int(
-        ( $seconds_left - $hours * SECONDS_IN_HOUR ) / SECONDS_IN_MINUTE );
+      my $minutes = int( ( $seconds_left - $hours * SECONDS_IN_HOUR ) / SECONDS_IN_MINUTE );
 
-      my $seconds = $seconds_left
-        - ( $hours * SECONDS_IN_HOUR + $minutes * SECONDS_IN_MINUTE );
+      my $seconds = $seconds_left - ( $hours * SECONDS_IN_HOUR + $minutes * SECONDS_IN_MINUTE );
 
-      $self->get_logger->debug(
-        "$hours hours $minutes minutes $seconds seconds until expiry");
+      $self->get_logger->debug("$hours hours $minutes minutes $seconds seconds until expiry");
     }
 
     $expired = ( $seconds_left < 0 ) ? TRUE : FALSE;
@@ -985,8 +969,7 @@ sub format_credentials {
 
   my $credential_keys = $self->credential_keys;
 
-  return join EMPTY,
-    map { sprintf $format, $_, $credential_keys->{$_} // EMPTY }
+  return join EMPTY, map { sprintf $format, $_, $credential_keys->{$_} // EMPTY }
     keys %{$credential_keys};
 }
 
@@ -1003,8 +986,7 @@ sub get_aws_access_key_id {
     $self->set_credentials;
   }
 
-  my $access_key_id
-    = $self->decrypt( $self->get__access_key_id, $self->_fetch_passkey );
+  my $access_key_id = $self->decrypt( $self->get__access_key_id, $self->_fetch_passkey );
 
   if ( !$self->get_cache ) {
     $self->set__access_key_id(undef);
@@ -1022,8 +1004,7 @@ sub get_aws_secret_access_key {
     $self->set_credentials;
   }
 
-  my $secret_access_key
-    = $self->decrypt( $self->get__secret_access_key, $self->_fetch_passkey );
+  my $secret_access_key = $self->decrypt( $self->get__secret_access_key, $self->_fetch_passkey );
 
   if ( !$self->get_cache ) {
     $self->set__secret_access_key(undef);
@@ -1141,11 +1122,9 @@ sub rotate_passkey {
 
   if ( $new_passkey && !ref $new_passkey ) {
     if ( $self->get_cache ) {
-      $self->set_aws_access_key_id( $self->get_aws_access_key_id,
-        $new_passkey );
+      $self->set_aws_access_key_id( $self->get_aws_access_key_id, $new_passkey );
 
-      $self->set_aws_secret_access_key( $self->get_aws_secret_access_key,
-        $new_passkey );
+      $self->set_aws_secret_access_key( $self->get_aws_secret_access_key, $new_passkey );
 
       $self->set_token( $self->get_token, $new_passkey );
     }
@@ -1206,8 +1185,7 @@ sub get_role_credentials {
 ########################################################################
   my (%args) = @_;
 
-  my ( $account_id, $role_name, $access_token, $region )
-    = @args{qw(account_id role_name access_token region)};
+  my ( $account_id, $role_name, $access_token, $region ) = @args{qw(account_id role_name access_token region)};
 
   if ( !$access_token ) {
     $access_token = _get_access_token();
@@ -1225,21 +1203,16 @@ sub get_role_credentials {
 
   my $query = sprintf GET_ROLE_CREDENTIALS_QUERY, $account_id, $role_name;
 
-  my $url = sprintf 'https://%s/%s%s', $host, GET_ROLE_CREDENTIALS_URI,
-    $query;
+  my $url = sprintf 'https://%s/%s%s', $host, GET_ROLE_CREDENTIALS_URI, $query;
 
   my $rsp = $ua->get($url);
 
   croak "no response from get($url)\n"
     if !$rsp;
 
-  my $content = eval {
-    return decode_json( $rsp->content )
-      if $rsp && $rsp->content_type eq 'application/json';
-  };
+  my $content = eval { return decode_json( $rsp->content ) if $rsp && $rsp->content_type eq 'application/json'; };
 
-  croak sprintf "could not decode response from GetRoleCredentials\n%s",
-    $EVAL_ERROR
+  croak sprintf "could not decode response from GetRoleCredentials\n%s", $EVAL_ERROR
     if !$content;
 
   return $content->{roleCredentials}
@@ -1280,9 +1253,7 @@ sub _set_defaults {
 
   if ( !$self->get_user_agent ) {
     # set a very low timeout
-    $self->set_user_agent(
-      LWP::UserAgent->new( timeout => $self->get_timeout || DEFAULT_TIMEOUT )
-    );
+    $self->set_user_agent( LWP::UserAgent->new( timeout => $self->get_timeout || DEFAULT_TIMEOUT ) );
   }
 
   my $default_search_order = [ split /\s*,\s*/xsm, DEFAULT_SEARCH_ORDER ];
@@ -1552,13 +1523,11 @@ sub export_credentials {
 
   $credentials //= \%ENV;
 
-  my @cred_keys
-    = qw(AWS_ACCESS_KEY_ID AWS_SECRET_ACCESS_KEY AWS_SESSION_TOKEN);
+  my @cred_keys = qw(AWS_ACCESS_KEY_ID AWS_SECRET_ACCESS_KEY AWS_SESSION_TOKEN);
 
   @cred_keys = map { defined $credentials->{$_} ? $_ : () } @cred_keys;
 
-  return join "\n",
-    map { sprintf 'export %s=%s', $_, $credentials->{$_} } @cred_keys;
+  return join "\n", map { sprintf 'export %s=%s', $_, $credentials->{$_} } @cred_keys;
 }
 
 ########################################################################
@@ -1588,8 +1557,7 @@ sub main {
   }
 
   if ( $options{role} && $options{account} ) {
-    my $credentials = Amazon::Credentials::set_sso_credentials(
-      @options{qw(role account region)} );
+    my $credentials = Amazon::Credentials::set_sso_credentials( @options{qw(role account region)} );
 
     print {*STDOUT} export_credentials($credentials);
 
@@ -1682,7 +1650,7 @@ or pass your SSO role name and account ID...
  
 =head1 VERSION
 
-This document reverse to verion 1.1.24 of
+This document reverse to verion 1.1.25 of
 L<Amazon::Credentials>.
 
 =head1 METHODS AND SUBROUTINES
